import { select, 
        csv, 
        scaleLinear, 
        extent, 
        scaleBand,
        axisLeft,
        axisBottom,
        format } from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

/* These data will be loaded in the csv callback. */
let data;
let xColumn;
let yColumn;

/* Re-render the chart if x & y is changed. */
const onXColumnClicked = column => {
  xColumn = column;
  render();
}
const onYColumnClicked = column => {
  yColumn = column;
  render();
}

const render = () => {
  select('#x-menu').call(dropdownMenu, {
    options: data.columns,
    onOptionClicked: onXColumnClicked,
    selectedOption: xColumn
  })
  
  select('#y-menu').call(dropdownMenu, {
    options: data.columns,
    onOptionClicked: onXColumnClicked,
    selectedOption: yColumn
  })
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    yAxisLabel: yColumn,
    circleRadius: 8,
    margin: { top: 10, left: 70, right: 50, bottom: 60},
    width,
    height,
    data
  })
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
    /* Set the default to be mpg vs weight and call render */
    xColumn = data.columns[4];
  	yColumn = data.columns[0];
    render();
});